@@ -62,7 +62,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint signals [LAST_SIGNAL] = { 0, };
+static guint signals [LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE (GpmCell, gpm_cell, G_TYPE_OBJECT)
 
@@ -139,6 +139,11 @@ gpm_cell_refresh_hal_all (GpmCell *cell)
 		if (exists == FALSE && (unit->is_discharging == TRUE || unit->is_charging == TRUE)) {
 			gpm_warning ("could not read your battery's charge rate");
 		}
+		/* sanity check to less than 100W */
+		if (unit->rate > 100*1000) {
+			gpm_warning ("sanity checking rate from %i to 0", unit->rate);
+			unit->rate = 0;
+		}
 	}
 
 	/* sanity check that charge_level.percentage exists (if it should) */
@@ -297,6 +302,11 @@ hal_device_property_modified_cb (HalGDevice   *device,
 
 	} else if (strcmp (key, "battery.charge_level.rate") == 0) {
 		hal_gdevice_get_uint (device, key, &unit->rate, NULL);
+		/* sanity check to less than 100W */
+		if (unit->rate > 100*1000) {
+			gpm_warning ("sanity checking rate from %i to 0", unit->rate);
+			unit->rate = 0;
+		}
 
 	} else if (strcmp (key, "battery.charge_level.percentage") == 0) {
 		hal_gdevice_get_uint (device, key, &unit->percentage, NULL);
@@ -448,24 +458,39 @@ gpm_cell_get_icon (GpmCell *cell)
 gchar *
 gpm_cell_get_id (GpmCell *cell)
 {
+	GString *string;
 	gchar *id = NULL;
 
 	g_return_val_if_fail (cell != NULL, NULL);
 	g_return_val_if_fail (GPM_IS_CELL (cell), NULL);
 
-	/* try to use these in order of uniqueness */
+	string = g_string_new ("");
+
+	/* in an ideal world, model-capacity-serial */
+	if (cell->priv->model != NULL && strlen (cell->priv->model) > 2) {
+		g_string_append (string, cell->priv->model);
+		g_string_append_c (string, '-');
+	}
+	if (cell->priv->unit.charge_design > 0) {
+		g_string_append_printf (string, "%i", cell->priv->unit.charge_design);
+		g_string_append_c (string, '-');
+	}
 	if (cell->priv->serial != NULL && strlen (cell->priv->serial) > 2) {
-		/* serial number */
-		id = g_strdup (cell->priv->serial);
-	} else if (cell->priv->model != NULL && strlen (cell->priv->model) > 2) {
-		/* model number */
-		id = g_strdup (cell->priv->model);
+		g_string_append (string, cell->priv->serial);
+		g_string_append_c (string, '-');
+	}
+
+	/* make sure we are sane */
+	if (string->len == 0) {
+		/* just use something generic */
+		g_string_append (string, "generic_id");
 	} else {
-		/* just return something generic */
-		id = g_strdup ("generic_id");
+		/* remove trailing '-' */
+		g_string_set_size (string, string->len - 1);
 	}
 
 	/* the id may have invalid chars that need to be replaced */
+	id = g_string_free (string, FALSE);
 	g_strdelimit (id, "\\\t\"' /", '_');
 
 	return id;
@@ -764,6 +789,7 @@ gpm_cell_finalize (GObject *object)
 	g_free (cell->priv->model);
 	g_object_unref (cell->priv->phone);
 	g_object_unref (cell->priv->hal_device);
+	G_OBJECT_CLASS (gpm_cell_parent_class)->finalize (object);
 }
 
 /**
