@@ -31,9 +31,9 @@
 #include <dbus/dbus-glib.h>
 #include <math.h>
 #include <string.h>
+#include <gconf/gconf-client.h>
 
 #include <libhal-gmanager.h>
-#include <libhal-gcpufreq.h>
 
 #include "gpm-tray-icon.h"
 #include "gpm-common.h"
@@ -45,6 +45,10 @@
 #include "gpm-screensaver.h"
 #include "gpm-prefs-server.h"
 
+#ifdef HAVE_GCONF_DEFAULTS
+#include <polkit-gnome/polkit-gnome.h>
+#endif
+
 static void     gpm_prefs_class_init (GpmPrefsClass *klass);
 static void     gpm_prefs_init       (GpmPrefs      *prefs);
 static void     gpm_prefs_finalize   (GObject	    *object);
@@ -60,12 +64,14 @@ struct GpmPrefsPrivate
 	gboolean		 has_ambient;
 	gboolean		 has_button_lid;
 	gboolean		 has_button_suspend;
+	gboolean		 can_shutdown;
 	gboolean		 can_suspend;
 	gboolean		 can_hibernate;
 	GpmConf			*conf;
 	GpmScreensaver		*screensaver;
-	HalGCpufreq		*hal_cpufreq;
-	HalGCpufreqType		 cpufreq_types;
+#ifdef HAVE_GCONF_DEFAULTS
+	PolKitGnomeAction	*default_action;
+#endif
 };
 
 enum {
@@ -86,13 +92,6 @@ G_DEFINE_TYPE (GpmPrefs, gpm_prefs, G_TYPE_OBJECT)
 #define ACTION_BLANK_TEXT		_("Blank screen")
 #define ACTION_NOTHING_TEXT		_("Do nothing")
 
-/* The text that should appear in the processor combo box */
-#define CPUFREQ_NOTHING_TEXT		_("Do nothing")
-#define CPUFREQ_ONDEMAND_TEXT		_("Based on processor load")
-#define CPUFREQ_CONSERVATIVE_TEXT	_("Automatic power saving")
-#define CPUFREQ_POWERSAVE_TEXT		_("Maximum power saving")
-#define CPUFREQ_PERFORMANCE_TEXT	_("Always maximum speed")
-
 /* If sleep time in a slider is set to 61 it is considered as never */
 const int NEVER_TIME_ON_SLIDER = 61;
 
@@ -500,7 +499,9 @@ gpm_prefs_setup_action_combo (GpmPrefs     *prefs,
 	}
 
 	while (actions[i] != NULL) {
-		if (strcmp (actions[i], ACTION_SHUTDOWN) == 0) {
+		if ((strcmp (actions[i], ACTION_SHUTDOWN) == 0) && !prefs->priv->can_shutdown) {
+			gpm_debug ("Cannot add option, as cannot shutdown.");
+		} else if (strcmp (actions[i], ACTION_SHUTDOWN) == 0 && prefs->priv->can_shutdown) {
 			gtk_combo_box_append_text (GTK_COMBO_BOX (widget),
 						   ACTION_SHUTDOWN_TEXT);
 			n_added++;
@@ -696,134 +697,6 @@ conf_key_changed_cb (GpmConf     *conf,
 	}
 }
 
-/**
- * gpm_prefs_processor_combo_changed_cb:
- * @widget: The GtkWidget object
- * @gpm_pref_key: The GConf key for this preference setting.
- **/
-static void
-gpm_prefs_processor_combo_changed_cb (GtkWidget *widget,
-				      GpmPrefs  *prefs)
-{
-	gchar *value;
-	const gchar *policy;
-	gchar *gpm_pref_key;
-
-	value = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
-	if (value == NULL) {
-		gpm_warning ("active text failed");
-		return;
-	}
-	if (strcmp (value, CPUFREQ_ONDEMAND_TEXT) == 0) {
-		policy = CODE_CPUFREQ_ONDEMAND;
-	} else if (strcmp (value, CPUFREQ_CONSERVATIVE_TEXT) == 0) {
-		policy = CODE_CPUFREQ_CONSERVATIVE;
-	} else if (strcmp (value, CPUFREQ_POWERSAVE_TEXT) == 0) {
-		policy = CODE_CPUFREQ_POWERSAVE;
-	} else if (strcmp (value, CPUFREQ_PERFORMANCE_TEXT) == 0) {
-		policy = CODE_CPUFREQ_PERFORMANCE;
-	} else if (strcmp (value, CPUFREQ_NOTHING_TEXT) == 0) {
-		policy = CODE_CPUFREQ_NOTHING;
-	} else {
-		g_assert (FALSE);
-	}
-
-	g_free (value);
-	gpm_pref_key = (char *) g_object_get_data (G_OBJECT (widget), "conf_key");
-	gpm_debug ("Changing %s to %s", gpm_pref_key, policy);
-	gpm_conf_set_string (prefs->priv->conf, gpm_pref_key, policy);
-}
-
-/**
- * gpm_prefs_setup_action_combo:
- * @prefs: This prefs class instance
- * @widget_name: The GtkWidget name
- * @gpm_pref_key: The GConf key for this preference setting.
- * @actions: The actions to associate in an array.
- **/
-static void
-gpm_prefs_setup_processor_combo (GpmPrefs         *prefs,
-				 const gchar      *widget_name,
-				 const gchar      *gpm_pref_key,
-				 HalGCpufreqType cpufreq_types)
-{
-	gchar *value;
-	guint n_added = 0;
-	gboolean has_option = FALSE;
-	gboolean is_writable;
-	GtkWidget *widget;
-	HalGCpufreqType cpufreq_type;
-
-	widget = glade_xml_get_widget (prefs->priv->glade_xml, widget_name);
-	gpm_conf_get_string (prefs->priv->conf, gpm_pref_key, &value);
-	gpm_conf_is_writable (prefs->priv->conf, gpm_pref_key, &is_writable);
-
-	gtk_widget_set_sensitive (widget, is_writable);
-
-	if (value == NULL) {
-		gpm_warning ("invalid schema, please re-install");
-		value = g_strdup ("nothing");
-	}
-
-	g_object_set_data (G_OBJECT (widget), "conf_key", (gpointer) gpm_pref_key);
-	g_signal_connect (G_OBJECT (widget), "changed",
-			  G_CALLBACK (gpm_prefs_processor_combo_changed_cb),
-			  prefs);
-
-	cpufreq_type = hal_gcpufreq_string_to_enum (value);
-
-	if (cpufreq_types & LIBHAL_CPUFREQ_ONDEMAND) {
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget),
-					   CPUFREQ_ONDEMAND_TEXT);
-		if (cpufreq_type == LIBHAL_CPUFREQ_ONDEMAND) {
-			gtk_combo_box_set_active (GTK_COMBO_BOX (widget), n_added);
-			has_option = TRUE;
-		}
-		n_added++;
-	}
-	if (cpufreq_types & LIBHAL_CPUFREQ_NOTHING) {
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget),
-					   CPUFREQ_NOTHING_TEXT);
-		if (cpufreq_type == LIBHAL_CPUFREQ_ONDEMAND) {
-			gtk_combo_box_set_active (GTK_COMBO_BOX (widget), n_added);
-			has_option = TRUE;
-		}
-		n_added++;
-	}
-	if (cpufreq_types & LIBHAL_CPUFREQ_CONSERVATIVE) {
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget),
-					   CPUFREQ_CONSERVATIVE_TEXT);
-		if (cpufreq_type == LIBHAL_CPUFREQ_CONSERVATIVE) {
-			gtk_combo_box_set_active (GTK_COMBO_BOX (widget), n_added);
-			has_option = TRUE;
-		}
-		n_added++;
-	}
-	if (cpufreq_types & LIBHAL_CPUFREQ_POWERSAVE) {
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget),
-					   CPUFREQ_POWERSAVE_TEXT);
-		if (cpufreq_type == LIBHAL_CPUFREQ_POWERSAVE) {
-			gtk_combo_box_set_active (GTK_COMBO_BOX (widget), n_added);
-			has_option = TRUE;
-		}
-		n_added++;
-	}
-	if (cpufreq_types & LIBHAL_CPUFREQ_PERFORMANCE) {
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget),
-					   CPUFREQ_PERFORMANCE_TEXT);
-		if (cpufreq_type == LIBHAL_CPUFREQ_PERFORMANCE) {
-			gtk_combo_box_set_active (GTK_COMBO_BOX (widget), n_added);
-			has_option = TRUE;
-		}
-		n_added++;
-	}
-
-	if (has_option == FALSE || cpufreq_type == LIBHAL_CPUFREQ_NOTHING) {
-		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), n_added);
-	}
-	g_free (value);
-}
-
 /** setup the notification page */
 static void
 prefs_setup_notification (GpmPrefs *prefs)
@@ -918,7 +791,6 @@ prefs_setup_ac (GpmPrefs *prefs)
 {
 	GtkWidget *widget;
 	gint delay;
-	gboolean show_cpufreq;
 	const gchar  *button_lid_actions[] =
 				{ACTION_NOTHING,
 				 ACTION_BLANK,
@@ -930,8 +802,6 @@ prefs_setup_ac (GpmPrefs *prefs)
 	gpm_prefs_setup_action_combo (prefs, "combobox_ac_lid",
 				      GPM_CONF_BUTTON_LID_AC,
 				      button_lid_actions);
-	gpm_prefs_setup_processor_combo (prefs, "combobox_ac_cpu",
-					 GPM_CONF_CPUFREQ_POLICY_AC, prefs->priv->cpufreq_types);
 	gpm_prefs_setup_sleep_slider (prefs, "hscale_ac_computer",
 				      GPM_CONF_TIMEOUT_SLEEP_COMPUTER_AC);
 	gpm_prefs_setup_sleep_slider (prefs, "hscale_ac_display",
@@ -950,22 +820,12 @@ prefs_setup_ac (GpmPrefs *prefs)
 		widget = glade_xml_get_widget (prefs->priv->glade_xml, "hbox_ac_lid");
 		gtk_widget_hide_all (widget);
 	}
-	if (prefs->priv->hal_cpufreq == NULL) {
-		widget = glade_xml_get_widget (prefs->priv->glade_xml, "hbox_ac_cpu");
-		gtk_widget_hide_all (widget);
-	}
 	if (prefs->priv->has_lcd == FALSE) {
 		widget = glade_xml_get_widget (prefs->priv->glade_xml, "hbox_ac_brightness");
 		gtk_widget_hide_all (widget);
 		widget = glade_xml_get_widget (prefs->priv->glade_xml, "checkbutton_ac_display_dim");
 		gtk_widget_hide_all (widget);
 	}
-
-	gpm_conf_get_bool (prefs->priv->conf, GPM_CONF_UI_SHOW_CPUFREQ, &show_cpufreq);
-	if (show_cpufreq == FALSE) {
-		widget = glade_xml_get_widget (prefs->priv->glade_xml, "hbox_ac_cpu");
-		gtk_widget_hide_all (widget);
-	}
 }
 
 static void
@@ -975,7 +835,6 @@ prefs_setup_battery (GpmPrefs *prefs)
 	GtkWidget *notebook;
 	gint delay;
 	gint page;
-	gboolean show_cpufreq;
 
 	const gchar  *button_lid_actions[] =
 				{ACTION_NOTHING,
@@ -1005,8 +864,6 @@ prefs_setup_battery (GpmPrefs *prefs)
 	gpm_prefs_setup_action_combo (prefs, "combobox_battery_critical",
 				      GPM_CONF_ACTIONS_CRITICAL_BATT,
 				      battery_critical_actions);
-	gpm_prefs_setup_processor_combo (prefs, "combobox_battery_cpu",
-					 GPM_CONF_CPUFREQ_POLICY_BATT, prefs->priv->cpufreq_types);
 	gpm_prefs_setup_sleep_slider (prefs, "hscale_battery_computer",
 				      GPM_CONF_TIMEOUT_SLEEP_COMPUTER_BATT);
 	gpm_prefs_setup_sleep_slider (prefs, "hscale_battery_display",
@@ -1032,21 +889,10 @@ prefs_setup_battery (GpmPrefs *prefs)
 		widget = glade_xml_get_widget (prefs->priv->glade_xml, "hbox_battery_lid");
 		gtk_widget_hide_all (widget);
 	}
-	if (prefs->priv->hal_cpufreq == NULL) {
-		widget = glade_xml_get_widget (prefs->priv->glade_xml, "hbox_battery_cpu");
-		gtk_widget_hide_all (widget);
-	}
 	if (prefs->priv->has_lcd == FALSE) {
-		widget = glade_xml_get_widget (prefs->priv->glade_xml, "hbox_battery_brightness");
-		gtk_widget_hide_all (widget);
 		widget = glade_xml_get_widget (prefs->priv->glade_xml, "checkbutton_battery_display_dim");
 		gtk_widget_hide_all (widget);
 	}
-	gpm_conf_get_bool (prefs->priv->conf, GPM_CONF_UI_SHOW_CPUFREQ, &show_cpufreq);
-	if (show_cpufreq == FALSE) {
-		widget = glade_xml_get_widget (prefs->priv->glade_xml, "hbox_battery_cpu");
-		gtk_widget_hide_all (widget);
-	}
 }
 
 static void
@@ -1119,6 +965,96 @@ prefs_setup_general (GpmPrefs *prefs)
 	}
 }
 
+#ifdef HAVE_GCONF_DEFAULTS
+/**
+ * pk_prefs_set_defaults_cb:
+ **/
+static void
+pk_prefs_set_defaults_cb (PolKitGnomeAction *default_action, GpmPrefs *prefs)
+{
+	DBusGProxy *proxy;
+	DBusGConnection *connection;
+	GError *error;
+	gchar *keys[5] = {
+		"/apps/gnome-power-manager/actions",
+		"/apps/gnome-power-manager/ui",
+		"/apps/gnome-power-manager/buttons",
+		"/apps/gnome-power-manager/backlight",
+		"/apps/gnome-power-manager/timeout"
+	};
+
+	error = NULL;
+	connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);
+	if (error != NULL) {
+		g_warning ("failed to get system bus connection: %s", error->message);
+		g_error_free (error);
+		return;
+	}
+
+	proxy = dbus_g_proxy_new_for_name (connection,
+					   "org.gnome.GConf.Defaults",
+					   "/",
+					   "org.gnome.GConf.Defaults");
+	if (proxy == NULL) {
+		g_warning ("Cannot connect to defaults mechanism");
+		return;
+	}
+
+	GConfClient *client;
+	client = gconf_client_get_default ();
+	gconf_client_suggest_sync (client, NULL);
+	g_object_unref (client);
+	dbus_g_proxy_call (proxy, "SetSystem", &error,
+			   G_TYPE_STRV, keys,
+			   G_TYPE_STRV, NULL,
+			   G_TYPE_INVALID, G_TYPE_INVALID);
+
+	g_object_unref (proxy);
+}
+
+/**
+ * gpk_prefs_create_custom_widget:
+ **/
+static GtkWidget *
+gpk_prefs_create_custom_widget (GladeXML *xml, gchar *func_name, gchar *name,
+				     gchar *string1, gchar *string2,
+				     gint int1, gint int2, gpointer user_data)
+{
+	GpmPrefs *prefs = GPM_PREFS (user_data);
+	if (strcmp (name, "button_default") == 0) {
+		return polkit_gnome_action_create_button (prefs->priv->default_action);
+	}
+	gpm_warning ("name unknown=%s", name);
+	return NULL;
+}
+
+/**
+ * gpk_prefs_setup_policykit:
+ *
+ * We have to do this before the glade stuff if done as the custom handler needs the actions setup
+ **/
+static void
+gpk_prefs_setup_policykit (GpmPrefs *prefs)
+{
+	PolKitAction *pk_action;
+
+	g_return_if_fail (GPM_IS_PREFS (prefs));
+
+	/* set default */
+	pk_action = polkit_action_new ();
+	polkit_action_set_action_id (pk_action, "org.freedesktop.packagekit.set-defaults");
+	prefs->priv->default_action = polkit_gnome_action_new_default ("set-defaults", pk_action,
+								       _("Make Default"), NULL);
+	g_object_set (prefs->priv->default_action,
+		      "no-icon-name", GTK_STOCK_FLOPPY,
+		      "auth-icon-name", GTK_STOCK_FLOPPY,
+		      "yes-icon-name", GTK_STOCK_FLOPPY,
+		      "self-blocked-icon-name", GTK_STOCK_FLOPPY,
+		      NULL);
+	polkit_action_unref (pk_action);
+}
+#endif
+
 /**
  * gpm_prefs_init:
  * @prefs: This prefs class instance
@@ -1132,8 +1068,6 @@ gpm_prefs_init (GpmPrefs *prefs)
 
 	prefs->priv = GPM_PREFS_GET_PRIVATE (prefs);
 
-	prefs->priv->hal_cpufreq = hal_gcpufreq_new ();
-
 	prefs->priv->screensaver = gpm_screensaver_new ();
 	g_signal_connect (prefs->priv->screensaver, "gs-delay-changed",
 			  G_CALLBACK (gs_delay_changed_cb), prefs);
@@ -1149,17 +1083,18 @@ gpm_prefs_init (GpmPrefs *prefs)
 	prefs->priv->has_ambient = ((caps & GPM_PREFS_SERVER_AMBIENT) > 0);
 	prefs->priv->has_button_lid = ((caps & GPM_PREFS_SERVER_LID) > 0);
 	prefs->priv->has_button_suspend = TRUE;
+	prefs->priv->can_shutdown = gpm_dbus_method_bool ("CanShutdown");
 	prefs->priv->can_suspend = gpm_dbus_method_bool ("CanSuspend");
 	prefs->priv->can_hibernate = gpm_dbus_method_bool ("CanHibernate");
 	gpm_debug ("caps=%i", caps);
 
-	/* only enable cpufreq stuff if we have the hardware */
-	if (prefs->priv->hal_cpufreq) {
-		hal_gcpufreq_get_governors (prefs->priv->hal_cpufreq,
-					    &prefs->priv->cpufreq_types);
-	} else {
-		prefs->priv->cpufreq_types = LIBHAL_CPUFREQ_NOTHING;
-	}
+#ifdef HAVE_GCONF_DEFAULTS
+	/* use custom widgets */
+	glade_set_custom_handler (gpk_prefs_create_custom_widget, prefs);
+
+	/* we have to do this before we connect up the glade file */
+	gpk_prefs_setup_policykit (prefs);
+#endif
 
 	prefs->priv->glade_xml = glade_xml_new (GPM_DATA "/gpm-prefs.glade", NULL, NULL);
 	if (prefs->priv->glade_xml == NULL) {
@@ -1185,6 +1120,11 @@ gpm_prefs_init (GpmPrefs *prefs)
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gpm_prefs_help_cb), prefs);
 
+#ifdef HAVE_GCONF_DEFAULTS
+	g_signal_connect (prefs->priv->default_action, "activate",
+			  G_CALLBACK (pk_prefs_set_defaults_cb), prefs);
+#endif
+
 	prefs_setup_ac (prefs);
 	prefs_setup_battery (prefs);
 	prefs_setup_ups (prefs);
@@ -1212,9 +1152,6 @@ gpm_prefs_finalize (GObject *object)
 	if (prefs->priv->screensaver) {
 		g_object_unref (prefs->priv->screensaver);
 	}
-	if (prefs->priv->hal_cpufreq) {
-		g_object_unref (prefs->priv->hal_cpufreq);
-	}
 
 	G_OBJECT_CLASS (gpm_prefs_parent_class)->finalize (object);
 }
